@@ -21,6 +21,7 @@
 ##
 ## ---------------------------------------------------------------------
 import sys
+import warnings
 
 from .LazyMp import LazyMp
 from .Tensor import Tensor
@@ -57,11 +58,11 @@ __all__ = ["run_adc", "AdcMatrix", "AdcBlockView", "AdcMatrixlike", "AdcMethod",
            "guesses_singlet", "guesses_triplet", "guesses_any",
            "guess_symmetries", "guesses_spin_flip", "guess_zero",
            "DefaultCachingPolicy", "GatherStatisticsPolicy", "LazyMp",
-           "adc0", "adc1", "adc2", "adc2x", "adc3",
+           "adc0", "cis", "adc1", "adc2", "adc2x", "adc3",
            "cvs_adc0", "cvs_adc1", "cvs_adc2", "cvs_adc2x", "cvs_adc3",
            "banner"]
 
-__version__ = "0.14.2"
+__version__ = "0.14.3"
 __license__ = "GPL v3"
 __url__ = "https://adc-connect.org"
 __authors__ = ["Michael F. Herbst", "Maximilian Scheurer"]
@@ -79,6 +80,13 @@ def adc0(*args, **kwargs):
     return run_adc(*args, **kwargs, method="adc0")
 
 
+@with_runadc_doc
+def cis(*args, **kwargs):
+    warnings.warn("CIS is an untested feature. Use with caution.")
+    state = run_adc(*args, **kwargs, method="adc1")
+    return ExcitedStates(state, property_method="adc0")
+
+
 @with_runadc_doc
 def adc1(*args, **kwargs):
     return run_adc(*args, **kwargs, method="adc1")
